@@ -1027,14 +1027,6 @@ Ztring Fims_Transform_Metadata(Ztring &ToReturn, MediaInfo_Internal &MI, size_t
 //---------------------------------------------------------------------------
 Ztring Export_Fims::Transform(MediaInfo_Internal &MI, version Version)
 {
-    //Current date/time is ISO format
-    time_t Seconds=time(NULL);
-    Ztring DateTime; DateTime.Date_From_Seconds_1970((int32u)Seconds);
-    DateTime.FindAndReplace(__T("UTC "), __T(""));
-    DateTime.FindAndReplace(__T(" "), __T("T"));
-    Ztring Date=DateTime.substr(0, 10);
-    Ztring Time=DateTime.substr(11, 8);
-
     size_t As11_Core_Pos=(size_t)-1;
     size_t As11_Segmentation_Pos=(size_t)-1;
     size_t As11_UkDpp_Pos=(size_t)-1;
@@ -1055,7 +1047,20 @@ Ztring Export_Fims::Transform(MediaInfo_Internal &MI, version Version)
     ToReturn+=__T("<!-- Generated by ")+MediaInfoLib::Config.Info_Version_Get()+__T(" -->\n");
     ToReturn+=__T("<!-- Based on EBUCore -->\n");
     ToReturn+=__T("<!-- Preliminary version (not for production) -->\n");
-    ToReturn+=__T("<!-- dateLastModified=\"")+Date+__T("\" timeLastModified=\"")+Time+__T("Z\" -->\n");
+    ToReturn+=__T("<!-- Generated");
+    time_t Time=time(NULL);
+    Ztring TimeS; TimeS.Date_From_Seconds_1970((int32u)Time);
+    if (!TimeS.empty())
+    {
+        TimeS.FindAndReplace(__T("UTC "), __T(""));
+        TimeS.FindAndReplace(__T(" "), __T("T"));
+        TimeS+=__T('Z');
+        ToReturn+=__T(" at ");
+        ToReturn+=TimeS;
+    }
+    ToReturn+=__T(" by ");
+    ToReturn+=MediaInfoLib::Config.Info_Version_Get();
+    ToReturn+=__T(" -->\n");
     if (Version==Version_1_1)
         ToReturn+=__T("<bms:bmContent xmlns:desc=\"http://description.fims.tv\" xmlns:tim=\"http://baseTime.fims.tv\"\n    xmlns:bms=\"http://base.fims.tv\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n    xsi:schemaLocation=\"http://base.fims.tv https://mediaarea.net/temp/baseMediaService-V1_1_0.xsd\">\n");
     if (Version==Version_1_2)
@@ -1070,27 +1075,21 @@ Ztring Export_Fims::Transform(MediaInfo_Internal &MI, version Version)
     ToReturn+=__T("\t\t\t<bms:resourceID/>\n");
 
     //bmContentFormats - resourceCreationDate
-    if (!MI.Get(Stream_General, 0, General_Encoded_Date).empty())
+    Ztring Encoded_Date=MI.Get(Stream_General, 0, General_Encoded_Date);
+    if (!Encoded_Date.size())
     {
-        Ztring DateTime=MI.Get(Stream_General, 0, General_Encoded_Date);
-        DateTime.FindAndReplace(__T("UTC "), __T(""));
-        DateTime.FindAndReplace(__T(" "), __T("T"));
-        Ztring Date=DateTime.substr(0, 10);
-        Ztring Time=DateTime.substr(11, 8);
-
-        ToReturn+=__T("\t\t\t<bms:resourceCreationDate>")+Date+__T('T')+Time+__T("Z</bms:resourceCreationDate>\n");
+        Encoded_Date.FindAndReplace(__T(" UTC"), __T("Z"));
+        Encoded_Date.FindAndReplace(__T(" "), __T("T"));
+        ToReturn+=__T("\t\t\t<bms:resourceCreationDate>")+Encoded_Date+__T("Z</bms:resourceCreationDate>\n");
     }
 
     //bmContentFormats - dateModified
-    if (!MI.Get(Stream_General, 0, General_Tagged_Date).empty())
+    Ztring Tagged_Date=MI.Get(Stream_General, 0, General_Tagged_Date);
+    if (!Tagged_Date.empty())
     {
-        Ztring DateTime=MI.Get(Stream_General, 0, General_Tagged_Date);
-        DateTime.FindAndReplace(__T("UTC "), __T(""));
-        DateTime.FindAndReplace(__T(" "), __T("T"));
-        Ztring Date=DateTime.substr(0, 10);
-        Ztring Time=DateTime.substr(11, 8);
-
-        ToReturn+=__T("\t\t\t<bms:resourceModifiedDate>")+Date+__T('T')+Time+__T("Z</bms:resourceModifiedDate>\n");
+        Tagged_Date.FindAndReplace(__T(" UTC"), __T("Z"));
+        Tagged_Date.FindAndReplace(__T(" "), __T("T"));
+        ToReturn+=__T("\t\t\t<bms:resourceModifiedDate>")+Tagged_Date+__T("Z</bms:resourceModifiedDate>\n");
     }
 
     //bmContentFormats - bmEssenceLocators
