@@ -40,6 +40,9 @@
 #if defined(MEDIAINFO_MPEGA_YES)
     #include "MediaInfo/Audio/File_Mpega.h"
 #endif
+#if defined(MEDIAINFO_AAC_YES)
+    #include "MediaInfo/Audio/File_Aac.h"
+#endif
 #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 #if MEDIAINFO_DEMUX
     #include "ThirdParty/base64/base64.h"
@@ -55,6 +58,8 @@ namespace MediaInfoLib
 // Constants
 //***************************************************************************
 
+extern std::string Id3v2_PictureType(int8u Type);
+
 static const char* Wm_CodecList_Kind(int32u Kind)
 {
     switch (Kind)
@@ -389,6 +394,7 @@ void File_Wm::Header_StreamProperties_Audio ()
             case 0x0161 :
             case 0x0162 :
             case 0x0163 : Header_StreamProperties_Audio_WMA(); break;
+            case 0x1610 : Header_StreamProperties_Audio_HEAac(); break;
             case 0x7A21 :
             case 0x7A22 : Header_StreamProperties_Audio_AMR(); break;
             default     : Skip_XX(Data_Size,                    "Unknown");
@@ -428,6 +434,21 @@ void File_Wm::Header_StreamProperties_Audio_WMA ()
     Skip_L4(                                                    "SuperBlockAlign");
 }
 
+//---------------------------------------------------------------------------
+void File_Wm::Header_StreamProperties_Audio_HEAac()
+{
+    //Parsing
+    #if defined(MEDIAINFO_AAC_YES)
+        File_Aac* MI=new File_Aac();
+        MI->Mode=File_Aac::Mode_HEAACWAVEFORMAT;
+        Open_Buffer_Init(MI);
+        Open_Buffer_Continue(MI);
+        Stream[Stream_Number].Parser=MI;
+    #else //MEDIAINFO_AAC_YES
+        Skip_XX(Element_Size-Element_Offset,                    "HEAACWAVEFORMAT");
+    #endif
+}
+
 //---------------------------------------------------------------------------
 void File_Wm::Header_StreamProperties_Audio_AMR ()
 {
@@ -1111,6 +1132,31 @@ void File_Wm::Header_ExtendedContentDescription()
             case 0x00 : Get_UTF16L(Value_Length, Value,         "Value"); break;
             case 0x01 :
                         if (Name==__T("ASFLeakyBucketPairs")) Header_ExtendedContentDescription_ASFLeakyBucketPairs(Value_Length);
+                        else if (Name==__T("WM/Picture")) {
+                            Ztring Mime, Description;
+                            int32u Data_Size;
+                            int8u PictureType;
+                            Get_L1 (PictureType,                                    "Picture Ttype"); Element_Info1(Id3v2_PictureType(PictureType));
+                            Get_L4 (Data_Size,                                      "Data size");
+                            if (Value_Length<5 || Data_Size>Value_Length-5)
+                                return; //There is a problem
+                            int64u End = Element_Offset;
+                            while (End + 1 < Element_Size && *(int16u*)(Buffer + Buffer_Offset + End)) {
+                                End += 2;
+                            }
+                            Get_UTF16L (End-Element_Offset, Mime,                   "Mime Type");
+                            Skip_L2(                                                "Zero");
+                            End = Element_Offset;
+                            while (End + 1 < Element_Size && *(int16u*)(Buffer + Buffer_Offset + End)) {
+                                End += 2;
+                            }
+                            Get_UTF16L (End-Element_Offset, Description,            "Description");
+                            Skip_L2(                                                "Zero");
+                            auto Element_Size_Save = Element_Size;
+                            Element_Size = Element_Offset + Data_Size;
+                            Attachment("WM/Picture", Description, Id3v2_PictureType(PictureType).c_str(), Mime, true);
+                            Element_Size = Element_Size_Save;
+                        }
                         else {Skip_XX(Value_Length,             "Value"); Value=__T("(Binary)");} break;
             case 0x02 : {int32u Value_Int; Get_L4 (Value_Int,   "Value"); Value=(Value_Int==0)?__T("No"):__T("Yes"); Value_Int64=Value_Int;} break;
             case 0x03 : {int32u Value_Int; Get_L4 (Value_Int,   "Value"); Value.From_Number(Value_Int); Value_Int64=Value_Int;} break;
@@ -1197,8 +1243,6 @@ void File_Wm::Header_ExtendedContentDescription()
                 Fill(Stream_General, 0, General_LawRating, Value);
             else if (Name==__T("WM/ParentalRatingReason"))
                 Fill(Stream_General, 0, General_LawRating_Reason, Value);
-            else if (Name==__T("WM/Picture"))
-                Fill(Stream_General, 0, General_Cover, "Y");
             else if (Name==__T("WM/Provider"))
                 Fill(Stream_General, 0, "Provider", Value);
             else if (Name==__T("WM/Publisher"))
