@@ -22,7 +22,9 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Text/File_Pdf.h"
-#include "MediaInfo/Tag/File_Xmp.h"
+#if defined(MEDIAINFO_XMP_YES)
+    #include "MediaInfo/Tag/File_Xmp.h"
+#endif
 #include <cstdlib>
 #include <algorithm>
 using namespace std;
@@ -539,12 +541,14 @@ void File_Pdf::Object_Metadata()
             if (Element_Offset<Element_Size && Buffer[Buffer_Offset+(size_t)Element_Offset]=='\n')
                 Element_Offset++;
 
+            #if defined(MEDIAINFO_XMP_YES)
             File_Xmp MI;
             Open_Buffer_Init(&MI, Length);
             Open_Buffer_Continue(&MI, Buffer+Buffer_Offset+(size_t)Element_Offset, Length);
-            Skip_XX(Length,                                     "Stream, Data");
             Open_Buffer_Finalize(&MI);
             Merge(MI, Stream_General, 0, 0);
+            #endif
+            Skip_XX(Length,                                     "Stream, Data");
         }
     }
 }
